==> tinyerp-server_3.1.99+3.2.0rc1.orig.tar.gz: tinyerp-server-3.2.0/bin/addons/account/partner.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id: account.py 1005 2005-07-25 08:41:42Z nicoe $
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import time
import netsvc
from osv import fields, osv
import ir



class res_partner(osv.osv):
	_name = 'res.partner'
	_inherit = 'res.partner'
	_description = 'Partner'
	def _credit_get(self, cr, uid, ids, prop, unknow_none, unknow_dict):
		res={}
		try:
			for id in ids:
				acc = ir.ir_get(cr, uid, 'meta', 'account.receivable', [('res.partner',id)])[0][2]
				cr.execute('select sum(debit-credit) from account_move_line where account_id=%d and partner_id=%d and reconcile_id is null', (acc, id))
				res[id]=cr.fetchone()[0] or 0.0
		except:
			for id in ids:
				res[id]=0.0
		return res

	def _debit_get(self, cr, uid, ids, prop, unknow_none, unknow_dict):
		res={}
		try:
			for id in ids:
				acc = ir.ir_get(cr, uid, 'meta', 'account.payable', [('res.partner',id)])[0][2]
				cr.execute('select sum(debit-credit) from account_move_line where account_id=%d and partner_id=%d and reconcile_id is null', (acc, id))
				res[id]=cr.fetchone()[0] or 0.0
		except:
			for id in ids:
				res[id]=0.0
		return res

	def _credit_search(self, cr, uid, obj, name, args):
		if not len(args):
			return []
		where = ' and '.join(map(lambda x: '(sum(debit-credit)'+x[1]+str(x[2])+')',args))
		cr.execute('select partner_id from account_move_line where account_id in (select id from account_account where type=%s) and reconcile_id is null group by partner_id having '+where, ('receivable',) )
		res = cr.fetchall()
		if not len(res):
			return [('id','=','0')]
		return [('id','in',map(lambda x:x[0], res))]

	def _debit_search(self, cr, uid, obj, name, args):
		if not len(args):
			return []
		where = ' and '.join(map(lambda x: '(sum(debit-credit)'+x[1]+str(x[2])+')',args))
		cr.execute('select partner_id from account_move_line where account_id in (select id from account_account where type=%s) and reconcile_id is null group by partner_id having '+where, ('payable',) )
		res = cr.fetchall()
		if not len(res):
			return [('id','=','0')]
		return [('id','in',map(lambda x:x[0], res))]

	_columns = {
		'credit': fields.function(_credit_get, fnct_search=_credit_search, method=True, string='Credit'),
		'debit': fields.function(_debit_get, fnct_search=_debit_search, method=True, string='Debit'),
		'debit_limit': fields.float('Limit Credit'),
		'credit_limit': fields.float('Limit Debit'),
		'payment_term': fields.many2one('account.payment.term', 'Payment Term'),
	}
res_partner()

==> tinyerp-server_3.3.0.orig.tar.gz: tinyerp-server-3.3.0/bin/addons/account/partner.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id: account.py 1005 2005-07-25 08:41:42Z nicoe $
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from osv import fields, osv
import ir

class res_partner(osv.osv):
	_name = 'res.partner'
	_inherit = 'res.partner'
	_description = 'Partner'
	def _credit_get(self, cr, uid, ids, prop, unknow_none, unknow_dict):
		res={}
		try:
			for id in ids:
				acc = ir.ir_get(cr, uid, 'meta', 'account.receivable', [('res.partner',id)])[0][2]
				cr.execute('select sum(debit-credit) from account_move_line where account_id=%d and partner_id=%d and reconcile_id is null', (acc, id))
				res[id]=cr.fetchone()[0] or 0.0
		except:
			for id in ids:
				res[id]=0.0
		return res

	def _debit_get(self, cr, uid, ids, prop, unknow_none, unknow_dict):
		res={}
		try:
			for id in ids:
				acc = ir.ir_get(cr, uid, 'meta', 'account.payable', [('res.partner',id)])[0][2]
				cr.execute('select sum(debit-credit) from account_move_line where account_id=%d and partner_id=%d and reconcile_id is null', (acc, id))
				res[id]=cr.fetchone()[0] or 0.0
		except:
			for id in ids:
				res[id]=0.0
		return res

	def _credit_search(self, cr, uid, obj, name, args):
		if not len(args):
			return []
		where = ' and '.join(map(lambda x: '(sum(debit-credit)'+x[1]+str(x[2])+')',args))
		cr.execute('select partner_id from account_move_line where account_id in (select id from account_account where type=%s) and reconcile_id is null group by partner_id having '+where, ('receivable',) )
		res = cr.fetchall()
		if not len(res):
			return [('id','=','0')]
		return [('id','in',map(lambda x:x[0], res))]

	def _debit_search(self, cr, uid, obj, name, args):
		if not len(args):
			return []
		where = ' and '.join(map(lambda x: '(sum(debit-credit)'+x[1]+str(x[2])+')',args))
		cr.execute('select partner_id from account_move_line where account_id in (select id from account_account where type=%s) and reconcile_id is null group by partner_id having '+where, ('payable',) )
		res = cr.fetchall()
		if not len(res):
			return [('id','=','0')]
		return [('id','in',map(lambda x:x[0], res))]

	_columns = {
		'credit': fields.function(_credit_get, fnct_search=_credit_search, method=True, string='Receivable'),
		'debit': fields.function(_debit_get, fnct_search=_debit_search, method=True, string='Payable'),
		'debit_limit': fields.float('Debit Limit'),
		'credit_limit': fields.float('Credit Limit'),
		'payment_term': fields.many2one('account.payment.term', 'Payment Term'),
	}
res_partner()
